Raygun.Plug.State
This wraps an agent used at compile time to save a function passed in by the router so it can be used before compiling the remaining macros.
Summary
| get() | |
| set(value) | |
| start_link() |
This wraps an agent used at compile time to save a function passed in by the router so it can be used before compiling the remaining macros.
| get() | |
| set(value) | |
| start_link() |